@@ -283,7 +283,7 @@ public:
 	//! Destroys the TQextScintilla instance.
 	virtual ~TQextScintilla();
 
-	//! Returns TRUE if auto-completion lists are case sensitive.
+	//! Returns true if auto-completion lists are case sensitive.
 	//!
 	//! \sa setAutoCompletionCaseSensitivity()
 	bool autoCompletionCaseSensitivity();
@@ -293,14 +293,14 @@ public:
     //! \sa setAutoCompletionFillups(), setAutoCompletionFillupsEnabled()
     bool autoCompletionFillupsEnabled();
 
-	//! Returns TRUE if the rest of the word to the right of the current
+	//! Returns true if the rest of the word to the right of the current
 	//! cursor is removed when an item from an auto-completion list is
 	//! selected.
 	//!
 	//! \sa setAutoCompletionReplaceWord()
 	bool autoCompletionReplaceWord();
 
-	//! Returns TRUE if the only item in an auto-completion list with a
+	//! Returns true if the only item in an auto-completion list with a
 	//! single entry is automatically used and the list not displayed.
 	//!
 	//! \sa setAutoCompletionShowSingle()
@@ -318,13 +318,13 @@ public:
 	//! \sa setAutoCompletionThreshold()
 	int autoCompletionThreshold() const {return acThresh;}
 
-	//! Returns TRUE if auto-indentation is enabled.
+	//! Returns true if auto-indentation is enabled.
 	//!
 	//! \sa setAutoIndent()
 	bool autoIndent() const {return autoInd;}
 
-	//! Returns TRUE if the backspace key unindents a line instead of
-	//! deleting a character.  The default is FALSE.
+	//! Returns true if the backspace key unindents a line instead of
+	//! deleting a character.  The default is false.
 	//!
 	//! \sa setBackspaceUnindents(), tabIndents(), setTabIndents()
 	bool backspaceUnindents();
@@ -402,22 +402,22 @@ public:
 	//! \sa setEolVisibility()
 	bool eolVisibility();
 
-	//! Find the next occurrence of the string \a expr and return TRUE if
-	//! \a expr was found, otherwise returns FALSE.  If \a expr is found it
+	//! Find the next occurrence of the string \a expr and return true if
+	//! \a expr was found, otherwise returns false.  If \a expr is found it
 	//! becomes the current selection.
 	//!
-	//! If \a re is TRUE then \a expr is interpreted as a regular
+	//! If \a re is true then \a expr is interpreted as a regular
 	//! expression rather than a simple string.
 	//!
-	//! If \a cs is TRUE then the search is case sensitive.
+	//! If \a cs is true then the search is case sensitive.
 	//!
-	//! If \a wo is TRUE then the search looks for whole word matches only,
+	//! If \a wo is true then the search looks for whole word matches only,
 	//! otherwise it searches for any matching text.
 	//!
-	//! If \a wrap is TRUE then the search wraps around the end of the
+	//! If \a wrap is true then the search wraps around the end of the
 	//! text.
 	//!
-	//! If \a forward is TRUE (the default) then the search is forward from
+	//! If \a forward is true (the default) then the search is forward from
 	//! the starting position to the end of the text, otherwise it is
 	//! backwards to the beginning of the text. 
 	//!
@@ -425,13 +425,13 @@ public:
 	//! search begins from the current cursor position.  Otherwise the
 	//! search begins at position \a index of line \a line.
 	//!
-	//! If \a show is TRUE (the default) then any text found is made
+	//! If \a show is true (the default) then any text found is made
 	//! visible (ie. it is unfolded).
 	//!
 	//! \sa findNext(), replace()
 	virtual bool findFirst(const TQString &expr,bool re,bool cs,bool wo,
-			       bool wrap,bool forward = TRUE,int line = -1,
-			       int index = -1,bool show = TRUE);
+			       bool wrap,bool forward = true,int line = -1,
+			       int index = -1,bool show = true);
 
 	//! Find the next occurence of the string found using findFirst().
 	//!
@@ -464,7 +464,7 @@ public:
 	void getSelection(int *lineFrom,int *indexFrom,
 			  int *lineTo,int *indexTo);
 
-	//! Returns TRUE if some text is selected.
+	//! Returns true if some text is selected.
 	//!
 	//! \sa selectedText()
 	bool hasSelectedText() const {return selText;}
@@ -474,13 +474,13 @@ public:
 	//! \sa setIndentation()
 	int indentation(int line);
 
-	//! Returns TRUE if the display of indentation guides is enabled.
+	//! Returns true if the display of indentation guides is enabled.
 	//!
 	//! \sa setIndentationGuides()
 	bool indentationGuides();
 
-	//! Returns TRUE if indentations are created using tabs and spaces,
-	//! rather than just spaces.  The default is TRUE.
+	//! Returns true if indentations are created using tabs and spaces,
+	//! rather than just spaces.  The default is true.
 	//!
 	//! \sa setIndentationsUseTabs()
 	bool indentationsUseTabs();
@@ -491,34 +491,34 @@ public:
 	//! \sa setIndentationWidth(), tabWidth()
 	int indentationWidth();
 
-	//! Returns TRUE if a call tip is currently active.
+	//! Returns true if a call tip is currently active.
 	bool isCallTipActive();
 
-	//! Returns TRUE if an auto-completion or user defined list is
+	//! Returns true if an auto-completion or user defined list is
 	//! currently active.
 	bool isListActive();
 
-	//! Returns TRUE if the text has been modified.
+	//! Returns true if the text has been modified.
 	//!
 	//! \sa setModified(), modificationChanged()
 	bool isModified();
 
-	//! Returns TRUE if the text edit is read-only.
+	//! Returns true if the text edit is read-only.
 	//!
 	//! \sa setReadOnly()
 	bool isReadOnly();
 
-	//! Returns TRUE if there is something that can be redone.
+	//! Returns true if there is something that can be redone.
 	//!
 	//! \sa redo()
 	bool isRedoAvailable();
 
-	//! Returns TRUE if there is something that can be undone.
+	//! Returns true if there is something that can be undone.
 	//!
 	//! \sa undo()
 	bool isUndoAvailable();
 
-	//! Returns TRUE if text is interpreted as being UTF8 encoded.  The
+	//! Returns true if text is interpreted as being UTF8 encoded.  The
 	//! default is to interpret the text as Latin1 encoded.
 	//!
 	//! \sa setUtf8()
@@ -543,7 +543,7 @@ public:
 	//! \sa setLexer()
 	TQextScintillaLexer *lexer() const;
 
-	//! Returns TRUE if line numbers are enabled for margin \a margin.
+	//! Returns true if line numbers are enabled for margin \a margin.
 	//!
 	//! \sa setMarginLineNumbers(), TQextScintillaBase::SCI_GETMARGINTYPEN
 	bool marginLineNumbers(int margin);
@@ -554,7 +554,7 @@ public:
 	//! TQextScintillaBase::SCI_GETMARGINMASKN
 	int marginMarkerMask(int margin);
 
-	//! Returns TRUE if margin \a margin is sensitive to mouse clicks.
+	//! Returns true if margin \a margin is sensitive to mouse clicks.
 	//!
 	//! \sa setMarginSensitivity(), marginClicked(),
 	//! TQextScintillaBase::SCI_GETMARGINTYPEN
@@ -831,8 +831,8 @@ public:
 	//! The standard command set is returned.
 	TQextScintillaCommandSet *standardCommands() const {return stdCmds;}
 
-	//! Returns TRUE if the tab key indents a line instead of inserting a
-	//! tab character.  The default is TRUE.
+	//! Returns true if the tab key indents a line instead of inserting a
+	//! tab character.  The default is true.
 	//!
 	//! \sa setTabIndents(), backspaceUnindents(), setBackspaceUnindents()
 	bool tabIndents();
@@ -923,7 +923,7 @@ public slots:
 	//! pressed.  If \a children is not set (the default) then only the top
 	//! level fold points are affected, otherwise the state of all fold
 	//! points are changed.
-	virtual void foldAll(bool children = FALSE);
+	virtual void foldAll(bool children = false);
 
 	//! If the line \a line is folded then it is unfolded.  Otherwise it is
 	//! folded.  This has the same effect as clicking in the fold margin.
@@ -969,35 +969,35 @@ public slots:
 	//! \sa setSelectionForegroundColor(), resetSelectionBackgroundColor()
 	virtual void resetSelectionForegroundColor();
 
-	//! If \a select is TRUE (the default) then all the text is selected.
-	//! If \a select is FALSE then any currently selected text is
+	//! If \a select is true (the default) then all the text is selected.
+	//! If \a select is false then any currently selected text is
 	//! deselected.
-	virtual void selectAll(bool select = TRUE);
+	virtual void selectAll(bool select = true);
 
 	//! If the cursor is either side of a brace character then move it to
 	//! the position of the corresponding brace and select the text between
 	//! the braces.
 	virtual void selectToMatchingBrace();
 
-	//! If \a cs is TRUE then auto-completion lists are case sensitive.
-	//! The default is TRUE.
+	//! If \a cs is true then auto-completion lists are case sensitive.
+	//! The default is true.
 	//!
 	//! \sa autoCompletionCaseSensitivity()
 	virtual void setAutoCompletionCaseSensitivity(bool cs);
 
-	//! If \a replace is TRUE then when an item from an auto-completion
+	//! If \a replace is true then when an item from an auto-completion
 	//! list is selected, the rest of the word to the right of the current
-	//! cursor is removed.  The default is FALSE.
+	//! cursor is removed.  The default is false.
 	//!
 	//! \sa autoCompletionReplaceWord()
 	virtual void setAutoCompletionReplaceWord(bool replace);
 
-	//! If \a single is TRUE then when there is only a single entry in an
+	//! If \a single is true then when there is only a single entry in an
 	//! auto-completion list it is automatically used and the list is not
 	//! displayed.  This only has an effect when auto-completion is
 	//! explicitly requested (using autoCompleteFromAPIs() and
 	//! autoCompleteFromDocument()) and has no effect when auto-completion
-	//! is triggered as the user types.  The default is FALSE.
+	//! is triggered as the user types.  The default is false.
 	//!
 	//! \sa autoCompletionShowSingle()
 	virtual void setAutoCompletionShowSingle(bool single);
@@ -1018,8 +1018,8 @@ public slots:
 	//! \sa autoCompletionThreshold(), setAutoCompletionStartCharacters()
 	virtual void setAutoCompletionThreshold(int thresh);
 
-	//! If \a autoindent is TRUE then auto-indentation is enabled.  The
-	//! default is FALSE.
+	//! If \a autoindent is true then auto-indentation is enabled.  The
+	//! default is false.
 	//!
 	//! \sa autoIndent()
 	virtual void setAutoIndent(bool autoindent);
@@ -1030,7 +1030,7 @@ public slots:
 	//! \sa braceMatching()
 	virtual void setBraceMatching(BraceMatch bm);
 
-	//! If \a deindent is TRUE then the backspace key will unindent a line
+	//! If \a deindent is true then the backspace key will unindent a line
 	//! rather then delete a character.
 	//!
 	//! \sa backspaceUnindents(), tabIndents(), setTabIndents()
@@ -1072,7 +1072,7 @@ public slots:
 	//! \sa eolMode()
 	virtual void setEolMode(EolMode mode);
 
-	//! If \a visible is TRUE then end-of-lines are made visible.  The
+	//! If \a visible is true then end-of-lines are made visible.  The
 	//! default is that they are invisible.
 	//!
 	//! \sa eolVisibility()
@@ -1105,7 +1105,7 @@ public slots:
 	//! \sa setIndentationGuidesBackgroundColor()
 	virtual void setIndentationGuidesForegroundColor(const TQColor &col);
 
-	//! If \a tabs is TRUE then indentations are created using tabs and
+	//! If \a tabs is true then indentations are created using tabs and
 	//! spaces, rather than just spaces.
 	//!
 	//! \sa indentationsUseTabs()
@@ -1172,8 +1172,8 @@ public slots:
 	virtual void setMarginWidth(int margin,const TQString &s);
 
 	//! Sets the modified state of the text edit to \a m.  Note that it is
-	//! only possible to clear the modified state (where \a m is FALSE).
-	//! Attempts to set the modified state (where \a m is TRUE) are
+	//! only possible to clear the modified state (where \a m is false).
+	//! Attempts to set the modified state (where \a m is true) are
 	//! ignored.
 	//!
 	//! \sa isModified(), modificationChanged()
@@ -1209,7 +1209,7 @@ public slots:
 	//! \sa resetSelectionForegroundColor(), setSelectionBackgroundColor()
 	virtual void setSelectionForegroundColor(const TQColor &col);
 
-	//! If \a indent is TRUE then the tab key will indent a line rather
+	//! If \a indent is true then the tab key will indent a line rather
 	//! then insert a tab character.
 	//!
 	//! \sa tabIndents(), backspaceUnindents(), setBackspaceUnindents()
@@ -1226,7 +1226,7 @@ public slots:
 	//! \sa text()
 	virtual void setText(const TQString &text);
 
-	//! Sets the current text encoding.  If \a cp is TRUE then UTF8 is
+	//! Sets the current text encoding.  If \a cp is true then UTF8 is
 	//! used, otherwise Latin1 is used.
 	//!
 	//! \sa isUtf8()
@@ -1300,9 +1300,9 @@ signals:
 	void cursorPositionChanged(int line,int pos);
 
 	//! This signal is emitted whenever text is selected or de-selected.
-	//! \a yes is TRUE if text has been selected and FALSE if text has been
-	//! deselected.  If \a yes is TRUE then copy() can be used to copy the
-	//! selection to the clipboard.  If \a yes is FALSE then copy() does
+	//! \a yes is true if text has been selected and false if text has been
+	//! deselected.  If \a yes is true then copy() can be used to copy the
+	//! selection to the clipboard.  If \a yes is false then copy() does
 	//! nothing. 
 	//!
 	//! \sa copy(), selectionChanged()
@@ -1324,7 +1324,7 @@ signals:
 	void modificationAttempted();
 
 	//! This signal is emitted whenever the modification state of the text
-	//! changes.  \a m is TRUE if the text has been modified.
+	//! changes.  \a m is true if the text has been modified.
 	//!
 	//! \sa isModified(), setModified()
 	void modificationChanged(bool m);
@@ -1388,7 +1388,7 @@ private:
 	long simpleFind();
 	void foldClick(int lineClick,int bstate);
 	void foldChanged(int line,int levelNow,int levelPrev);
-	void foldExpand(int &line,bool doExpand,bool force = FALSE,
+	void foldExpand(int &line,bool doExpand,bool force = false,
 			int visLevels = 0,int level = -1);
 	void setFoldMarker(int marknr,int mark = SC_MARK_EMPTY);
 	TQString convertText(const char *s);
